VisibilitiesABC
===============

.. currentmodule:: xrayvision.visibility

.. autoclass:: VisibilitiesABC
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~VisibilitiesABC.amplitude
      ~VisibilitiesABC.amplitude_uncertainty
      ~VisibilitiesABC.meta
      ~VisibilitiesABC.phase
      ~VisibilitiesABC.phase_center
      ~VisibilitiesABC.phase_uncertainty
      ~VisibilitiesABC.u
      ~VisibilitiesABC.uncertainty
      ~VisibilitiesABC.v
      ~VisibilitiesABC.visibilities

   .. rubric:: Attributes Documentation

   .. autoattribute:: amplitude
   .. autoattribute:: amplitude_uncertainty
   .. autoattribute:: meta
   .. autoattribute:: phase
   .. autoattribute:: phase_center
   .. autoattribute:: phase_uncertainty
   .. autoattribute:: u
   .. autoattribute:: uncertainty
   .. autoattribute:: v
   .. autoattribute:: visibilities
